@@ -4,7 +4,7 @@
  *  libnet
  *  libnet_dlpi.c - dlpi routines
  *
- *  Copyright (c) 1998, 1999 Mike D. Schiffman <mike@infonexus.com>
+ *  Copyright (c) 1998, 1999, 2000 Mike D. Schiffman <mike@infonexus.com>
  *  All rights reserved.
  *
  * Copyright (c) 1993, 1994, 1995, 1996, 1997
@@ -200,7 +200,7 @@ libnet_open_link_interface(char *device, char *ebuf)
         }
 
         cp = dname2;
-        while (*cp && !isdigit(*cp)) cp++;
+        while (*cp && !isdigit((int)*cp))) cp++;
         if (*cp) ppa = atoi(cp);
         else
         /*
